require 'quantify-amee'

describe "AMEE units" do
  
  include Quantify

  it "should include commonly used SI units" do
    Unit.metre.should be_loaded
    Unit.second.should be_loaded
    Unit.kg.should be_loaded
  end

  it "should include commonly used non SI units" do
    Unit.foot.should be_loaded
    Unit.pound.should be_loaded
    Unit.month.should be_loaded
  end

  it "should exclude uncommonly used SI units" do
    Unit.micrometre.should_not be_loaded
    lambda{Unit.galileo}.should raise_error
    lambda{Unit.inverse_centimetre}.should raise_error
  end

  it "should exclude uncommonly used non SI units" do
    lambda{Unit.astronomical_unit}.should raise_error
    lambda{Unit.dyne_centimetre}.should raise_error
    lambda{Unit.maxwell}.should raise_error
  end

  it "should include commonly used SI units and prefixes" do
    Unit.terajoule.should be_loaded
    Unit.gigagram.should be_loaded
    Unit.megawatt.should be_loaded
  end

  it "should include commonly used Non SI units and prefixes" do
    Unit.MBTU.should be_loaded
  end

  it "should exclude uncommonly used SI units and prefixes" do
    Unit.microjoule.should_not be_loaded
    Unit.nanogram.should_not be_loaded
    Unit.picowatt.should_not be_loaded
  end

  it "should represent the BTU with the 59F version" do
    Unit.BTU.label.should eql "BTU_FiftyNineF"
  end

  it "should label the unit for 'day' as 'day'" do
    Unit.day.label.should eql 'day'
  end

  it "should recognise the unit for megawatt_hour as 'MWh'" do
    Unit.megawatt_hour.label.should eql 'MWh'
    Unit.megawatt_hour.symbol.should eql 'MWh'
  end

  it "should use the correct symbol for a US ton" do
    Unit.ton_us.symbol.should eql 'ton (US)'
  end

  it "should use the correct symbol for a UK ton" do
    Unit.ton_uk.symbol.should eql 'ton (UK)'
  end

  it "should use the correct symbol for a US gallon" do
    Unit.gal.symbol.should eql 'gal (US)'
  end

  it "should use the correct symbol for a US dry gallon" do
    Unit.gallon_dry_us.symbol.should eql 'gal (US dry)'
  end

  it "should use the correct symbol for a UK gallon" do
    Unit.gal_uk.symbol.should eql 'gal (UK)'
  end

  it "should use the correct symbol for a US ton" do
    Unit.oz_fl.symbol.should eql 'fl oz (US)'
  end

end

